SingleBrowserLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers.locators
Class SingleBrowserLocator

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator

All Implemented Interfaces:
  BrowserLocator

Direct Known Subclasses:
  FirefoxLocator, GoogleChromeLocator, InternetExplorerLocator, SafariLocator

    public abstract class SingleBrowserLocator

extends java.lang.Object
implements BrowserLocator

Discovers a valid browser installation on local system.

Constructor Summary
`SingleBrowserLocator()`

Method Summary
`protected BrowserInstallation` | `browserDefaultPath()`
`protected abstract java.lang.String` | `browserName()`
`protected abstract java.lang.String` | `browserPathOverridePropertyName()`
`java.lang.String` | `computeLibraryPath(java.io.File launcherPath)`
`protected java.lang.String` | `couldNotFindAnyInstallationMessage()`
`protected java.lang.String` | `fakeLauncherPath()`
`protected BrowserInstallation` | `findAtADefaultLocation()`
`BrowserInstallation` | `findBrowserLocation()`
`BrowserInstallation` | `findBrowserLocationOrFail()`
`BrowserInstallation` | `findFileInPath(java.lang.String fileName)`
`protected BrowserInstallation` | `findInPath()`
`protected java.lang.String` | `humanFriendlyLauncherFileNames()`
`protected BrowserInstallation` | `retrieveValidInstallationPath(java.io.File launcher)`
`BrowserInstallation` | `retrieveValidInstallationPath(java.lang.String launcher)`
`protected BrowserInstallation` | `retrieveValidInstallationPath(java.lang.String dirname, java.lang.String fileName)`
`protected abstract java.lang.String` | `seleniumBrowserName()`
`protected abstract java.lang.String[]` | `standardlauncherFilenames()`
`protected abstract java.lang.String[]` | `usualLauncherLocations()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### SingleBrowserLocator

    public SingleBrowserLocator()

Method Detail

### findBrowserLocationOrFail

    public BrowserInstallation findBrowserLocationOrFail()

  Specified by:
    `findBrowserLocationOrFail` in interface `BrowserLocator`

### findBrowserLocation

    public BrowserInstallation findBrowserLocation()

### browserName

    protected abstract java.lang.String browserName()

### standardlauncherFilenames

    protected abstract java.lang.String[] standardlauncherFilenames()

### seleniumBrowserName

    protected abstract java.lang.String seleniumBrowserName()

### browserPathOverridePropertyName

    protected abstract java.lang.String browserPathOverridePropertyName()

### usualLauncherLocations

    protected abstract java.lang.String[] usualLauncherLocations()

### findInPath

    protected BrowserInstallation findInPath()

### findAtADefaultLocation

    protected BrowserInstallation findAtADefaultLocation()

### browserDefaultPath

    protected BrowserInstallation browserDefaultPath()

### findFileInPath

    public BrowserInstallation findFileInPath(java.lang.String fileName)

### couldNotFindAnyInstallationMessage

    protected java.lang.String couldNotFindAnyInstallationMessage()

### fakeLauncherPath

    protected java.lang.String fakeLauncherPath()

### humanFriendlyLauncherFileNames

    protected java.lang.String humanFriendlyLauncherFileNames()

### retrieveValidInstallationPath

    protected BrowserInstallation retrieveValidInstallationPath(java.lang.String dirname,
                                                                java.lang.String fileName)

### retrieveValidInstallationPath

    public BrowserInstallation retrieveValidInstallationPath(java.lang.String launcher)

  Specified by:
    `retrieveValidInstallationPath` in interface `BrowserLocator`

### retrieveValidInstallationPath

    protected BrowserInstallation retrieveValidInstallationPath(java.io.File launcher)

### computeLibraryPath

    public java.lang.String computeLibraryPath(java.io.File launcherPath)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.